@@ -1,5 +1,4 @@
 import json
-from json import JSONDecodeError
 
 __all__ = (
     'QuillParseError',
@@ -18,9 +17,9 @@ class QuillParseError(Exception):
 class Quill:
     def __init__(self, json_string):
         try:
-            self.json_string = json_string
-            json_data = json.loads(json_string)
+            self.json_string = json.dumps(json_string)
+            json_data = json_string
             self.delta = json_data['delta']
             self.html = json_data['html']
-        except (JSONDecodeError, KeyError, TypeError):
+        except (json.JSONDecodeError, KeyError, TypeError):
             raise QuillParseError(json_string)
